@@ -1,23 +1,23 @@
 import logging
-
 from logging import Logger
 from logging.handlers import TimedRotatingFileHandler
 
-from robinhood_commons.log.gzip_rotator import GZipRotator
-from robinhood_commons.util.constants import LOG_DIR
+from log.gzip_rotator import GZipRotator
 from robinhood_commons.util.io_utils import ensure_exists
 
 
-def create_logger(path):
+def create_logger(name: str) -> Logger:
     """
     Creates a rotating log
     """
-    ensure_exists(LOG_DIR)
 
-    logger = logging.getLogger(path.split('/')[-1].split('.')[0])
+    ensure_exists(name)
+
+    log_name: str = name.split('/')[-1]
+    logger = logging.getLogger(log_name.split('.')[0])
     logger.setLevel(logging.INFO)
 
-    log_handler = TimedRotatingFileHandler(filename=path, when='h')
+    log_handler = TimedRotatingFileHandler(filename=name, when='h')
 
     log_formatter = logging.Formatter('%(asctime)s [%(levelname)s] [%(name)s] %(message)s')
     log_handler.setFormatter(log_formatter)
@@ -35,5 +35,12 @@ def create_logger(path):
 
 
 if __name__ == '__main__':
-    the_logger: Logger = create_logger(f'{LOG_DIR}/log_utils.log')
+    from robinhood_commons.util.random_utils import random_float
+
+    path: str = f'/tmp/output/log_utils.{random_float(0, 100)}.log'
+
+    the_logger: Logger = create_logger(name=path)
     the_logger.info('help!')
+
+    import os
+    os.remove(path=path)
